# unitorch.models.blip

## BlipProcessor

::: unitorch.models.blip.BlipProcessor

## BlipForPretrain

::: unitorch.models.blip.BlipForPretrain

## BlipForClassification

::: unitorch.models.blip.BlipForClassification

## BlipForTextClassification

::: unitorch.models.blip.BlipForTextClassification

## BlipForImageClassification

::: unitorch.models.blip.BlipForImageClassification

## BlipForImageCaption

::: unitorch.models.blip.BlipForImageCaption
